==> r2dbc-mysql-0.8.1.RELEASE-sources.jar: dev/miku/r2dbc/mysql/TextParametrizedStatement.java <==
/*
 * Copyright 2018-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dev.miku.r2dbc.mysql;

import dev.miku.r2dbc.mysql.client.Client;
import dev.miku.r2dbc.mysql.codec.Codecs;
import dev.miku.r2dbc.mysql.message.server.ServerMessage;
import dev.miku.r2dbc.mysql.util.ConnectionContext;
import reactor.core.publisher.Flux;

import java.util.List;
import java.util.function.Function;

import static dev.miku.r2dbc.mysql.util.AssertUtils.requireNonNull;

/**
 * An implementation of {@link ParametrizedStatementSupport} based on MySQL text query.
 */
final class TextParametrizedStatement extends ParametrizedStatementSupport {

    private final TextQuery query;

    TextParametrizedStatement(Client client, Codecs codecs, ConnectionContext context, TextQuery query) {
        super(client, codecs, context, requireNonNull(query, "query must not be null").getParameters());
        this.query = query;
    }

    @Override
    protected Flux<MySqlResult> execute(List<Binding> bindings) {
        Function<Flux<ServerMessage>, MySqlResult> toResult = messages -> new MySqlResult(false, codecs, context, generatedKeyName, messages);
        return query.formatSql(bindings).concatMap(it -> QueryFlow.execute(client, it).map(toResult), 1);
    }

    @Override
    protected ParameterIndex getIndexes(String name) {
        return query.getIndexes(name);
    }
}

==> r2dbc-mysql-0.8.2.RELEASE-sources.jar: dev/miku/r2dbc/mysql/TextParametrizedStatement.java <==
/*
 * Copyright 2018-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dev.miku.r2dbc.mysql;

import dev.miku.r2dbc.mysql.client.Client;
import dev.miku.r2dbc.mysql.codec.Codecs;
import reactor.core.publisher.Flux;

import java.util.List;

import static dev.miku.r2dbc.mysql.util.AssertUtils.requireNonNull;

/**
 * An implementation of {@link ParametrizedStatementSupport} based on MySQL text query.
 */
final class TextParametrizedStatement extends ParametrizedStatementSupport {

    private final TextQuery query;

    TextParametrizedStatement(Client client, Codecs codecs, ConnectionContext context, TextQuery query) {
        super(client, codecs, context, requireNonNull(query, "query must not be null").getParameters());
        this.query = query;
    }

    @Override
    protected Flux<MySqlResult> execute(List<Binding> bindings) {
        return QueryFlow.execute(client, query, bindings)
            .map(messages -> new MySqlResult(false, codecs, context, generatedKeyName, messages));
    }

    @Override
    protected ParameterIndex getIndexes(String name) {
        return query.getIndexes(name);
    }
}
